@@ -2,6 +2,7 @@
 
 from __future__ import annotations
 
+import sys
 from pathlib import Path
 
 import pytest
@@ -369,6 +370,7 @@ class TestRealFolderStructure:
         if not src_dir.exists():
             pytest.skip("Real test structure not found")
 
+        # This test only reads files, doesn't modify them, so no backup needed
         finder = ExternalDependencyFinder(project_root, src_dir)
         analyzer = ImportAnalyzer(project_root)
 
@@ -392,12 +394,28 @@ class TestRealFolderStructure:
         if not src_dir.exists():
             pytest.skip("Real test structure not found")
 
+        # Save original repository files that might be modified
+        original_pyproject = project_root / "pyproject.toml"
+        original_readme = project_root / "README.md"
+        pyproject_backup = None
+        readme_backup = None
+        pyproject_existed = original_pyproject.exists()
+        readme_existed = original_readme.exists()
+
+        if pyproject_existed:
+            pyproject_backup = original_pyproject.read_bytes()
+        if readme_existed:
+            readme_backup = original_readme.read_bytes()
+
+        # Check what files exist before the build
+        some_globals_existed_before = (src_dir / "some_globals.py").exists()
+
         manager = BuildManager(project_root, src_dir)
 
-        # Prepare build
-        external_deps = manager.prepare_build()
-
         try:
+            # Prepare build
+            external_deps = manager.prepare_build()
+
             # Verify dependencies were found
             assert len(external_deps) >= 1
 
@@ -418,8 +436,36 @@ class TestRealFolderStructure:
             # Always cleanup
             manager.cleanup()
 
-            # Verify cleanup
-            assert not (src_dir / "some_globals.py").exists()
+            # Restore original repository files if they were modified
+            if pyproject_backup and original_pyproject.exists():
+                # Verify the file was restored correctly, or restore it manually
+                try:
+                    current_content = original_pyproject.read_bytes()
+                    if current_content != pyproject_backup:
+                        # File was modified, restore it
+                        original_pyproject.write_bytes(pyproject_backup)
+                except Exception as e:
+                    print(f"Warning: Could not verify/restore pyproject.toml: {e}", file=sys.stderr)
+            elif pyproject_backup and not original_pyproject.exists():
+                # File was deleted, restore it
+                original_pyproject.write_bytes(pyproject_backup)
+
+            if readme_backup and original_readme.exists():
+                # Verify the file was restored correctly, or restore it manually
+                try:
+                    current_content = original_readme.read_bytes()
+                    if current_content != readme_backup:
+                        # File was modified, restore it
+                        original_readme.write_bytes(readme_backup)
+                except Exception as e:
+                    print(f"Warning: Could not verify/restore README.md: {e}", file=sys.stderr)
+            elif readme_backup and not original_readme.exists():
+                # File was deleted, restore it
+                original_readme.write_bytes(readme_backup)
+
+            # Verify cleanup - only check if the file didn't exist before
+            if not some_globals_existed_before:
+                assert not (src_dir / "some_globals.py").exists()
             if (src_dir / "utility_folder").exists():
                 # May have been there originally, so just check it's not in copied_dirs
                 assert (src_dir / "utility_folder") not in manager.copied_dirs
@@ -454,6 +500,19 @@ class TestExclusionPatterns:
         if not src_dir.exists():
             pytest.skip("Real test structure not found")
 
+        # Save original repository files that might be modified
+        original_pyproject = project_root / "pyproject.toml"
+        original_readme = project_root / "README.md"
+        pyproject_backup = None
+        readme_backup = None
+        pyproject_existed = original_pyproject.exists()
+        readme_existed = original_readme.exists()
+
+        if pyproject_existed:
+            pyproject_backup = original_pyproject.read_bytes()
+        if readme_existed:
+            readme_backup = original_readme.read_bytes()
+
         manager = BuildManager(project_root, src_dir)
 
         try:
@@ -474,6 +533,27 @@ class TestExclusionPatterns:
         finally:
             manager.cleanup()
 
+            # Restore original repository files if they were modified
+            if pyproject_backup and original_pyproject.exists():
+                try:
+                    current_content = original_pyproject.read_bytes()
+                    if current_content != pyproject_backup:
+                        original_pyproject.write_bytes(pyproject_backup)
+                except Exception as e:
+                    print(f"Warning: Could not verify/restore pyproject.toml: {e}", file=sys.stderr)
+            elif pyproject_backup and not original_pyproject.exists():
+                original_pyproject.write_bytes(pyproject_backup)
+
+            if readme_backup and original_readme.exists():
+                try:
+                    current_content = original_readme.read_bytes()
+                    if current_content != readme_backup:
+                        original_readme.write_bytes(readme_backup)
+                except Exception as e:
+                    print(f"Warning: Could not verify/restore README.md: {e}", file=sys.stderr)
+            elif readme_backup and not original_readme.exists():
+                original_readme.write_bytes(readme_backup)
+
     def test_exclude_custom_patterns(self, test_project_root: Path) -> None:
         """Test that custom exclusion patterns work."""
         # Create a directory with a custom exclusion pattern
